@@ -36,7 +36,7 @@ import shutil
 import glob
 import posixpath
 import gtk
-import gtk.glade
+import devede_other
 import gobject
 import cairo
 if sys.platform=='win32':
@@ -58,8 +58,8 @@ class create_all:
 
 	def cancel_clicked(self,widget,temp=False):
 		
-		newtree=gtk.glade.XML(self.gladefile,"wcancel_job_dialog",domain="devede")
-		window=newtree.get_widget("wcancel_job_dialog")
+		newtree=devede_other.create_tree(self,"wcancel_job_dialog",self.gladefile,False)
+		window=newtree.get_object("wcancel_job_dialog")
 		window.show()
 		value=window.run()
 		window.hide()
@@ -72,8 +72,8 @@ class create_all:
 		gobject.source_remove(self.timer)
 		self.window.hide()
 		self.window.destroy()
-		newtree=gtk.glade.XML(self.gladefile,"waborted_dialog",domain="devede")
-		window=newtree.get_widget("waborted_dialog")
+		newtree=devede_other.create_tree(self,"waborted_dialog",self.gladefile,False)
+		window=newtree.get_object("waborted_dialog")
 		window.show()
 		window.run()
 		window.hide()
@@ -86,10 +86,10 @@ class create_all:
 
 	def iso_changed(self,args,arbol):
 
-		iso_name=arbol.get_widget("iso_filename")
-		iso_folder=arbol.get_widget("final_directory")
+		iso_name=arbol.get_object("iso_filename")
+		iso_folder=arbol.get_object("final_directory")
 	
-		w=arbol.get_widget("button_folder_accept")
+		w=arbol.get_object("button_folder_accept")
 	
 		mode=True
 	
@@ -151,19 +151,18 @@ class create_all:
 		self.gladefile=gladefile
 		self.structure=structure
 		self.global_vars=global_vars
-		self.tree=gtk.glade.XML(self.gladefile,"wprogress",domain="devede")
-		self.tree.signal_autoconnect(self)
+		self.tree=devede_other.create_tree(self,"wprogress",self.gladefile)
 		
-		self.window=self.tree.get_widget("wprogress")
-		self.partial=self.tree.get_widget("progresspartial")
+		self.window=self.tree.get_object("wprogress")
+		self.partial=self.tree.get_object("progresspartial")
 		self.erase_temp=global_vars["erase_temporary_files"]
 		self.iso_creator=global_vars["iso_creator"]
 
 		self.queue=[]
 		self.current_action=0
 		self.actions=global_vars["number_actions"]
-		self.total=self.tree.get_widget("progress_total")
-		self.label=self.tree.get_widget("lcreating")
+		self.total=self.tree.get_object("progress_total")
+		self.label=self.tree.get_object("lcreating")
 		self.total.set_fraction(0)
 		self.partial.set_fraction(0)
 		self.partial.set_text("0%")
@@ -193,12 +192,12 @@ class create_all:
 	def preview(self,filefolder):
 		
 		self.init_queue()
-		newtree=gtk.glade.XML(self.gladefile,"wpreview_dialog",domain="devede")
-		timev=newtree.get_widget("seconds_preview")
+		newtree=devede_other.create_tree(self,"wpreview_dialog",self.gladefile,False)
+		timev=newtree.get_object("seconds_preview")
 		timev.set_value(60)
-		path=newtree.get_widget("temporary_files")
+		path=newtree.get_object("temporary_files")
 		path.set_filename(filefolder)
-		w=newtree.get_widget("wpreview_dialog")
+		w=newtree.get_object("wpreview_dialog")
 		w.show()
 		ret=w.run()
 		w.hide()
@@ -249,8 +248,8 @@ class create_all:
 				break
 			
 		if empty:
-			newtree=gtk.glade.XML(self.gladefile,"wempty_titles_dialog",domain="devede")
-			w=newtree.get_widget("wempty_titles_dialog")
+			newtree=devede_other.create_tree(self,"wempty_titles_dialog",self.gladefile,False)
+			w=newtree.get_object("wempty_titles_dialog")
 			w.show()
 			value=w.run()
 			w.hide()
@@ -260,13 +259,13 @@ class create_all:
 
 		# ask the folder and filename
 		
-		newtree=gtk.glade.XML(self.gladefile,"wfolder_dialog",domain="devede")
-		wdir=newtree.get_widget("final_directory")
-		wfile=newtree.get_widget("iso_filename")
+		newtree=devede_other.create_tree(self,"wfolder_dialog",self.gladefile,False)
+		wdir=newtree.get_object("final_directory")
+		wfile=newtree.get_object("iso_filename")
 		wfile.set_text("movie")
 		wfile.connect("changed",self.iso_changed,newtree)
 		self.iso_changed("",newtree)
-		w=newtree.get_widget("wfolder_dialog")
+		w=newtree.get_object("wfolder_dialog")
 		w.show()
 		value=w.run()
 		
@@ -286,9 +285,9 @@ class create_all:
 			self.filefolder+=os.sep
 		
 		if (os.path.exists(filefolder2)):
-			newtree=gtk.glade.XML(self.gladefile,"wfolder_exists",domain="devede")
-			w=newtree.get_widget("wfolder_exists")
-			wtext=newtree.get_widget("folder_exists_label")
+			newtree=devede_other.create_tree(self,"wfolder_exists",self.gladefile,False)
+			w=newtree.get_object("wfolder_exists")
+			wtext=newtree.get_object("folder_exists_label")
 			wtext.set_text(_("The file or folder\n\n%(folder)s\n\nalready exists. If you continue, it will be deleted.") % {'folder':filefolder2})
 			w.show()
 			value=w.run()
@@ -419,8 +418,8 @@ class create_all:
 		 	else:
 		 		fname+="mpg"
 			parameters=[mplay,"-sid","0",fname]
-			newtree=gtk.glade.XML(self.gladefile,"wpreviewagain_dialog",domain="devede")
-			w=newtree.get_widget("wpreviewagain_dialog")
+			newtree=devede_other.create_tree(self,"wpreviewagain_dialog",self.gladefile,False)
+			w=newtree.get_object("wpreviewagain_dialog")
 			while True:
 				salida=devede_executor.executor("previewfile",self.filefolder,None)
 				salida.launch_program(parameters,output=False)
@@ -460,11 +459,11 @@ class create_all:
 
 		self.window.hide()
 		self.window.destroy()
-		newtree=gtk.glade.XML(self.gladefile,"wend_dialog",domain="devede")
-		label=newtree.get_widget("elapsed")
+		newtree=devede_other.create_tree(self,"wend_dialog",self.gladefile,False)
+		label=newtree.get_object("elapsed")
 		tiempo2=devede_other.return_time(time.time()-self.tiempo,True)
 		label.set_text(tiempo2)
-		window=newtree.get_widget("wend_dialog")
+		window=newtree.get_object("wend_dialog")
 		window.show()
 		window.run()
 		window.hide()
