@@ -22,9 +22,10 @@
 import pygtk # for testing GTK version number
 pygtk.require ('2.0')
 import gtk
-import gtk.glade
 import devede_main
 import devede_dialogs
+import os
+import devede_other
 
 class disctype:
 	
@@ -33,9 +34,8 @@ class disctype:
 		self.gladefile=global_vars["gladefile"]
 		self.global_vars=global_vars
 		
-		self.tree=gtk.glade.XML(self.gladefile,"wdisk_type",domain="devede")
-		self.tree.signal_autoconnect(self)
-		self.window=self.tree.get_widget("wdisk_type")
+		self.tree=devede_other.create_tree(self,"wdisk_type",self.gladefile)
+		self.window=self.tree.get_object("wdisk_type")
 		self.main_window=None
 		self.window.show()
 
@@ -43,13 +43,13 @@ class disctype:
 	def on_wdisk_type_delete_event(self,widget,signal):
 		""" Callback which shows the "Are you sure?" window """
 	
-		self.ask_cancel()
+		return self.ask_cancel()
 	
 	
 	def on_wdisk_type_cancel_clicked(self,widget):
 		""" Callback which shows the "Are you sure?" window """
 	
-		self.ask_cancel()
+		return self.ask_cancel()
 	
 	
 	def ask_cancel(self):
@@ -57,6 +57,8 @@ class disctype:
 		window=devede_dialogs.ask_exit(self.gladefile)
 		retval=window.run()
 		window=None
+		print "Retorno: ",
+		print retval
 		if retval==-5:
 			gtk.main_quit()
 			return False
