@@ -22,10 +22,10 @@
 import pygtk # for testing GTK version number
 pygtk.require ('2.0')
 import gtk
-import gtk.glade
 import cairo
 import os
 
+import devede_other
 import devede_dialogs
 import devede_xml_menu
 import devede_newfiles
@@ -41,14 +41,13 @@ class menu_options:
 		self.structure=structure
 		self.callback=callback
 		
-		self.tree=gtk.glade.XML(gladefile,"wmenu_properties",domain="devede")
-		self.tree.signal_autoconnect(self)
-		self.window=self.tree.get_widget("wmenu_properties")
+		self.tree=devede_other.create_tree(self,"wmenu_properties",self.gladefile)
+		self.window=self.tree.get_object("wmenu_properties")
 		
 		menu_filename=global_vars["menu_bg"]
 		if menu_filename==None:
 			menu_filename=os.path.join(global_vars["path"],"background.png")
-		w=self.tree.get_widget("menu_bg_file")
+		w=self.tree.get_object("menu_bg_file")
 		w.set_filename(menu_filename)
 		filter=gtk.FileFilter()
 		filter.add_mime_type("image/png")
@@ -66,7 +65,7 @@ class menu_options:
 		self.on_menu_bg_file_update_preview(w,menu_filename)
 		
 		self.adding_sound=True
-		w=self.tree.get_widget("menu_sound")
+		w=self.tree.get_object("menu_sound")
 		print "filtro"
 		filter2=gtk.FileFilter()
 		filter2.add_mime_type("audio/mpeg")
@@ -77,70 +76,70 @@ class menu_options:
 		w.set_filename(global_vars["menu_sound"])
 		print "Añado"
 		
-		w=self.tree.get_widget("menufont")
+		w=self.tree.get_object("menufont")
 		w.set_font_name(global_vars["fontname"])
 		
-		w=self.tree.get_widget("unselected_color")
+		w=self.tree.get_object("unselected_color")
 		color=global_vars["menu_font_color"]
 		c1=gtk.gdk.Color(color[0],color[1],color[2])
 		w.set_color(c1)
 		w.set_alpha(color[3])
 		
-		w=self.tree.get_widget("selected_color")
+		w=self.tree.get_object("selected_color")
 		color=global_vars["menu_selc_color"]
 		c1=gtk.gdk.Color(color[0],color[1],color[2])
 		w.set_color(c1)
 		
-		w=self.tree.get_widget("shadow_color")
+		w=self.tree.get_object("shadow_color")
 		color=global_vars["menu_shadow_color"]
 		c1=gtk.gdk.Color(color[0],color[1],color[2])
 		w.set_color(c1)
 		w.set_alpha(color[3])
 		
-		w=self.tree.get_widget("bg_color")
+		w=self.tree.get_object("bg_color")
 		color=global_vars["menu_bgcolor"]
 		c1=gtk.gdk.Color(color[0],color[1],color[2])
 		w.set_color(c1)
 		w.set_alpha(color[3])
 		
 		if global_vars["menu_alignment"]==0:
-			w=self.tree.get_widget("menutop")
+			w=self.tree.get_object("menutop")
 		elif global_vars["menu_alignment"]==1:
-			w=self.tree.get_widget("menubottom")
+			w=self.tree.get_object("menubottom")
 		else:
-			w=self.tree.get_widget("menumiddle")
+			w=self.tree.get_object("menumiddle")
 		w.set_active(True)
 		
 		if global_vars["menu_halignment"]==0:
-			w=self.tree.get_widget("menuleft")
+			w=self.tree.get_object("menuleft")
 		elif global_vars["menu_halignment"]==1:
-			w=self.tree.get_widget("menuright")
+			w=self.tree.get_object("menuright")
 		else:
-			w=self.tree.get_widget("menucenter")
+			w=self.tree.get_object("menucenter")
 		w.set_active(True)
 		
 		if global_vars["do_menu"]:
-			w=self.tree.get_widget("domenu")
+			w=self.tree.get_object("domenu")
 		else:
-			w=self.tree.get_widget("notmenu")
+			w=self.tree.get_object("notmenu")
 		w.set_active(True)
 		
-		w=self.tree.get_widget("menu_title_text")
+		w=self.tree.get_object("menu_title_text")
 		w.set_text(global_vars["menu_title_text"])
 		
-		w=self.tree.get_widget("menu_title_color")
+		w=self.tree.get_object("menu_title_color")
 		color=global_vars["menu_title_color"]
 		c1=gtk.gdk.Color(color[0],color[1],color[2])
 		w.set_color(c1)
 		w.set_alpha(color[3])
 		
-		w=self.tree.get_widget("menu_title_shadow")
+		w=self.tree.get_object("menu_title_shadow")
 		color=global_vars["menu_title_shadow"]
 		c1=gtk.gdk.Color(color[0],color[1],color[2])
 		w.set_color(c1)
 		w.set_alpha(color[3])
 		
-		w=self.tree.get_widget("menu_title_font")
+		w=self.tree.get_object("menu_title_font")
 		w.set_font_name(global_vars["menu_title_fontname"])
 		
 		self.window.show()
@@ -209,7 +208,7 @@ class menu_options:
 
 	def on_menu_no_sound_clicked(self,widget):
 		
-		w=self.tree.get_widget("menu_sound")
+		w=self.tree.get_object("menu_sound")
 		w.set_filename(os.path.join(self.global_vars["path"],"silence.mp3"))
 
 	def on_menu_help_clicked(self,widget):
@@ -243,19 +242,19 @@ class menu_options:
 	def on_menu_default_bg_clicked(self,widget):
 		
 		self.global_vars["menu_bg"]=self.global_vars["path"]+"background.png"
-		w=self.tree.get_widget("menu_bg_file")
+		w=self.tree.get_object("menu_bg_file")
 		w.set_filename(self.global_vars["menu_bg"])
 	
 	
 	def set_new_bg(self,global_vars):
 		
-		w=self.tree.get_widget("menu_bg_file")
+		w=self.tree.get_object("menu_bg_file")
 		menu_filename=w.get_filename()
 		if menu_filename==None:
 			menu_filename=self.global_vars["path"]+"background.png"
 		global_vars["menu_bg"]=menu_filename
 
-		w=self.tree.get_widget("menu_sound")
+		w=self.tree.get_object("menu_sound")
 		sound_filename=w.get_filename()
 		test=devede_newfiles.file_get_params()
 		check,channels=test.read_file_values(sound_filename,True)
@@ -263,60 +262,60 @@ class menu_options:
 		global_vars["menu_sound_duration"]=test.length
 		test=None
 
-		w=self.tree.get_widget("menufont")
+		w=self.tree.get_object("menufont")
 		global_vars["fontname"]=w.get_font_name()
 		
-		w=self.tree.get_widget("unselected_color")
+		w=self.tree.get_object("unselected_color")
 		color=w.get_color()
 		global_vars["menu_font_color"]=[color.red,color.green,color.blue,w.get_alpha()]
 				
-		w=self.tree.get_widget("selected_color")
+		w=self.tree.get_object("selected_color")
 		color=w.get_color()
 		global_vars["menu_selc_color"]=[color.red,color.green,color.blue,65535]
 		
-		w=self.tree.get_widget("shadow_color")
+		w=self.tree.get_object("shadow_color")
 		color=w.get_color()
 		global_vars["menu_shadow_color"]=[color.red,color.green,color.blue,w.get_alpha()]
 		
-		w=self.tree.get_widget("bg_color")
+		w=self.tree.get_object("bg_color")
 		color=w.get_color()
 		global_vars["menu_bgcolor"]=[color.red,color.green,color.blue,w.get_alpha()]
 
 		align=0 # top
-		w=self.tree.get_widget("menumiddle")
+		w=self.tree.get_object("menumiddle")
 		if w.get_active():
 			align=2 # middle
 		else:
-			w=self.tree.get_widget("menubottom")
+			w=self.tree.get_object("menubottom")
 			if w.get_active():
 				align=1 # bottom
 		global_vars["menu_alignment"]=align
 		
 		halign=0 # left
-		w=self.tree.get_widget("menucenter")
+		w=self.tree.get_object("menucenter")
 		if w.get_active():
 			halign=2 # middle
 		else:
-			w=self.tree.get_widget("menuright")
+			w=self.tree.get_object("menuright")
 			if w.get_active():
 				halign=1 # right
 		global_vars["menu_halignment"]=halign
 		
-		w=self.tree.get_widget("domenu")
+		w=self.tree.get_object("domenu")
 		global_vars["do_menu"]=w.get_active()
 		
-		w=self.tree.get_widget("menu_title_text")
+		w=self.tree.get_object("menu_title_text")
 		global_vars["menu_title_text"]=w.get_text()
 		
-		w=self.tree.get_widget("menu_title_color")
+		w=self.tree.get_object("menu_title_color")
 		color=w.get_color()
 		global_vars["menu_title_color"]=[color.red,color.green,color.blue,w.get_alpha()]
 		
-		w=self.tree.get_widget("menu_title_shadow")
+		w=self.tree.get_object("menu_title_shadow")
 		color=w.get_color()
 		global_vars["menu_title_shadow"]=[color.red,color.green,color.blue,w.get_alpha()]
 		
-		w=self.tree.get_widget("menu_title_font")
+		w=self.tree.get_object("menu_title_font")
 		global_vars["menu_title_fontname"]=w.get_font_name()
 		
 		# repaint the used size
@@ -343,15 +342,13 @@ class menu_preview:
 		
 		self.menu_preview=None
 		if global_vars["PAL"]:
-			newtree=gtk.glade.XML(gladefile,"wmenu_preview_pal",domain="devede")
-			newtree.signal_autoconnect(self)
-			window=newtree.get_widget("wmenu_preview_pal")
-			self.menu_preview=newtree.get_widget("preview_draw_pal")
+			newtree=devede_other.create_tree(self,"wmenu_preview_pal",gladefile)
+			window=newtree.get_object("wmenu_preview_pal")
+			self.menu_preview=newtree.get_object("preview_draw_pal")
 		else:
-			newtree=gtk.glade.XML(gladefile,"wmenu_preview_ntsc",domain="devede")
-			newtree.signal_autoconnect(self)
-			window=newtree.get_widget("wmenu_preview_ntsc")
-			self.menu_preview=newtree.get_widget("preview_draw_ntsc")
+			newtree=devede_other.create_tree(self,"wmenu_preview_ntsc",gladefile)
+			window=newtree.get_object("wmenu_preview_ntsc")
+			self.menu_preview=newtree.get_object("preview_draw_ntsc")
 		print self.menu_preview
 
 		if global_vars.has_key("install_path")==False:
