@@ -22,10 +22,10 @@
 import pygtk # for testing GTK version number
 pygtk.require ('2.0')
 import gtk
-import gtk.glade
 import pickle
 import os
 
+import devede_other
 import devede_dialogs
 import devede_newfiles
 
@@ -52,8 +52,8 @@ class load_save_config:
 				return
 
 		if file_name==None:
-			tree=gtk.glade.XML(self.gladefile,"wloadconfig",domain="devede")
-			window = tree.get_widget("wloadconfig")
+			tree=devede_other.create_tree(self,"wloadconfig",self.gladefile,False)
+			window = tree.get_object("wloadconfig")
 			
 			filter = gtk.FileFilter()
 			filter.add_pattern("*.devede")
@@ -216,9 +216,9 @@ class load_save_config:
 			self.global_vars["menu_title_fontname"]="Sans 14"
 
 		if global_vars2.has_key("erase_files")==False:
-			w=self.tree.get_widget("create_iso")
+			w=self.tree.get_object("create_iso")
 			w.set_active(True)
-			w=self.tree.get_widget("erase_files")
+			w=self.tree.get_object("erase_files")
 			w.set_active(True)
 
 		self.global_vars["struct_name"]=file_name # update the path
@@ -233,13 +233,13 @@ class load_save_config:
 			(from a previous save), it will overwrite the old file """
 	
 		if mode or (self.global_vars["struct_name"]==""):
-			tree=gtk.glade.XML(self.gladefile,"wsaveconfig",domain="devede")
-			saveconfig=tree.get_widget("wsaveconfig")
+			tree=devede_other.create_tree(self,"wsaveconfig",self.gladefile,False)
+			saveconfig=tree.get_object("wsaveconfig")
 			
 			filter=gtk.FileFilter()
 			filter.add_pattern("*.devede")
 			filter.set_name(".devede")
-			saveconfig=tree.get_widget("wsaveconfig")
+			saveconfig=tree.get_object("wsaveconfig")
 			saveconfig.add_filter(filter)
 			saveconfig.set_do_overwrite_confirmation(True)
 
@@ -290,11 +290,11 @@ class load_save_config:
 			vars["menu_title_text"]=self.global_vars["menu_title_text"]
 			vars["menu_title_fontname"]=self.global_vars["menu_title_fontname"]
 			
-			w=self.tree.get_widget("erase_files")
+			w=self.tree.get_object("erase_files")
 			vars["erase_files"]=w.get_active()
-			if self.tree.get_widget("create_iso").get_active():
+			if self.tree.get_object("create_iso").get_active():
 				vars["action_todo"]=2
-			elif self.tree.get_widget("create_dvd").get_active():
+			elif self.tree.get_object("create_dvd").get_active():
 				vars["action_todo"]=1
 			else:
 				vars["action_todo"]=0
