@@ -22,7 +22,6 @@
 import pygtk # for testing GTK version number
 pygtk.require ('2.0')
 import gtk
-import gtk.glade
 import gobject
 import os
 import sys
@@ -43,9 +42,9 @@ class main_window:
 		self.global_vars=global_vars
 		self.gladefile=global_vars["gladefile"]
 		
-		self.tree=gtk.glade.XML(self.gladefile,"wmain",domain="devede")
-		self.tree.signal_autoconnect(self)
-		self.window=self.tree.get_widget("wmain")
+		self.tree=devede_other.create_tree(self,"wmain",self.gladefile)
+		self.window=self.tree.get_object("wmain")
+
 		if sys.platform=="win32":
 			self.window.drag_dest_set(0,[],0)
 			self.window.connect('drag_drop', self.drop_cb)
@@ -56,8 +55,8 @@ class main_window:
 		self.list_titles=gtk.TreeStore(gobject.TYPE_PYOBJECT,gobject.TYPE_STRING)
 		self.list_chapters=gtk.TreeStore(gobject.TYPE_PYOBJECT,gobject.TYPE_STRING)
 		
-		ltitles=self.tree.get_widget("ltitles")
-		lchapters=self.tree.get_widget("lchapters")
+		ltitles=self.tree.get_object("ltitles")
+		lchapters=self.tree.get_object("lchapters")
 		
 		ltitles.set_model(self.list_titles)
 		lchapters.set_model(self.list_chapters)
@@ -78,9 +77,9 @@ class main_window:
 		self.callback=callback # callback to call to show again the SELECT_DISK dialog
 		
 		if global_vars["PAL"]:
-			w=self.tree.get_widget("default_pal")
+			w=self.tree.get_object("default_pal")
 		else:
-			w=self.tree.get_widget("default_ntsc")
+			w=self.tree.get_object("default_ntsc")
 		w.set_active(True)
 		
 		self.window.show()
@@ -154,22 +153,22 @@ class main_window:
 		self.disctocreate = self.global_vars["disctocreate"]
 		
 		# choose the default disk type
-		w = self.tree.get_widget("dvdsize")
+		w = self.tree.get_object("dvdsize")
 		if (self.disctocreate == "dvd") or (self.disctocreate == "divx"):
 			w.set_active(4)
 		else:
 			w.set_active(2)
 		
-		w = self.tree.get_widget("autosize")
+		w = self.tree.get_object("autosize")
 		if (self.disctocreate == "vcd"):
 			w.hide()
 		else:
 			w.show()
 		
-		w1 = self.tree.get_widget("frame1") # contains the titles
-		w2 = self.tree.get_widget("create_dvd") # toggle to create the DVD structure
-		w5 = self.tree.get_widget("menuoptions") # button to show the menu options
-		w6 = self.tree.get_widget("menu_preview") # button to preview the menu
+		w1 = self.tree.get_object("frame1") # contains the titles
+		w2 = self.tree.get_object("create_dvd") # toggle to create the DVD structure
+		w5 = self.tree.get_object("menuoptions") # button to show the menu options
+		w6 = self.tree.get_object("menu_preview") # button to preview the menu
 		
 		if self.disctocreate == "dvd":
 			w1.show()
@@ -183,38 +182,38 @@ class main_window:
 			w5.hide()
 			w6.hide()
 		
-		w1 = self.tree.get_widget("frame5") # ACTION frame
-		w2 = self.tree.get_widget("erase_files")
+		w1 = self.tree.get_object("frame5") # ACTION frame
+		w2 = self.tree.get_object("erase_files")
 		if self.disctocreate == "divx":
 			w1.hide()
 			w2.hide()
 			self.global_vars["action_todo"]=0
-			w = self.tree.get_widget("only_convert")
+			w = self.tree.get_object("only_convert")
 			w.set_active(True)
 		else:
 			w1.show()
 			w2.show()
 			if self.global_vars["action_todo"]==2:
-				w=self.tree.get_widget("create_iso")
+				w=self.tree.get_object("create_iso")
 			elif self.global_vars["action_todo"]==1:
-				w=self.tree.get_widget("create_dvd")
+				w=self.tree.get_object("create_dvd")
 			else:
-				w=self.tree.get_widget("only_convert")
+				w=self.tree.get_object("only_convert")
 				self.global_vars["action_todo"]=0
 			w.set_active(True)
 		
-		w=self.tree.get_widget("erase_files")
+		w=self.tree.get_object("erase_files")
 		w.set_active(self.global_vars["erase_files"])
 	
 		# now select the first title and chapter
 		
-		ltitles=self.tree.get_widget("ltitles")
+		ltitles=self.tree.get_object("ltitles")
 		ltitles.get_selection().select_path( (0,))
 		
-		lchapters=self.tree.get_widget("lchapters")
+		lchapters=self.tree.get_object("lchapters")
 		lchapters.get_selection().select_path( (0,))
 		
-		w=self.tree.get_widget("multicore")
+		w=self.tree.get_object("multicore")
 		if (self.global_vars["multicore"]==1):
 			w.set_active(False)
 		else:
@@ -491,18 +490,18 @@ class main_window:
 				return
 	
 		actions=0	
-		w=self.tree.get_widget("only_convert")
+		w=self.tree.get_object("only_convert")
 		if w.get_active():
 			actions=1
 		else:
-			w=self.tree.get_widget("create_dvd")
+			w=self.tree.get_object("create_dvd")
 			if (w.get_active()) or ((self.disctocreate!="dvd") and (self.disctocreate!="divx")):
 				actions=2
 			else:
 				actions=3
 	
 		self.global_vars["number_actions"]=actions
-		w=self.tree.get_widget("erase_files")
+		w=self.tree.get_object("erase_files")
 		self.global_vars["erase_temporary_files"]=w.get_active()
 		
 		print "Threads: "+str(self.global_vars["multicore"])
@@ -513,7 +512,7 @@ class main_window:
 	
 	def on_multicore_toggled(self,widget):
 		
-		w=self.tree.get_widget("multicore")
+		w=self.tree.get_object("multicore")
 		if w.get_active():
 			self.global_vars["multicore"]=self.get_cores()
 		else:
@@ -734,9 +733,9 @@ class main_window:
 		self.set_buttons()
 		self.set_title()
 		if self.global_vars["PAL"]:
-			w=self.tree.get_widget("default_pal")
+			w=self.tree.get_object("default_pal")
 		else:
-			w=self.tree.get_widget("default_ntsc")
+			w=self.tree.get_object("default_ntsc")
 		w.set_active(True)
 		load=None
 
@@ -790,8 +789,8 @@ class main_window:
 	
 		""" Returns the title and chapter currently marked in the main window """
 	
-		ltitles=self.tree.get_widget("ltitles")
-		lchapters=self.tree.get_widget("lchapters")
+		ltitles=self.tree.get_object("ltitles")
+		lchapters=self.tree.get_object("lchapters")
 	
 		try:
 			ctree,iter=ltitles.get_selection().get_selected()
@@ -823,13 +822,13 @@ class main_window:
 		else:
 			title_marked=True
 	
-		title_up=self.tree.get_widget("titleup")
+		title_up=self.tree.get_object("titleup")
 		if title==0:
 			title_up.set_sensitive(False)
 		else:
 			title_up.set_sensitive(True)
 		
-		title_down=self.tree.get_widget("titledown")
+		title_down=self.tree.get_object("titledown")
 		if (title+1)==len(self.structure):
 			title_down.set_sensitive(False)
 		else:
@@ -840,40 +839,40 @@ class main_window:
 		else:
 			chapter_marked=True
 	
-		files_up=self.tree.get_widget("filesup")
+		files_up=self.tree.get_object("filesup")
 		if chapter<2:
 			files_up.set_sensitive(False)
 		else:
 			files_up.set_sensitive(True)
 		
-		files_down=self.tree.get_widget("filesdown")
+		files_down=self.tree.get_object("filesdown")
 		if (chapter==-1) or (chapter+1==len(self.structure[title])):
 			files_down.set_sensitive(False)
 		else:
 			files_down.set_sensitive(True)
 	
-		del_title=self.tree.get_widget("del_title")
+		del_title=self.tree.get_object("del_title")
 		if len(self.structure)>1:
 			del_title.set_sensitive(title_marked)	
 		else:
 			del_title.set_sensitive(False)
 		
-		add_title=self.tree.get_widget("add_title")
+		add_title=self.tree.get_object("add_title")
 		if (len(self.structure)<61):
 			add_title.set_sensitive(True)
 		else:
 			add_title.set_sensitive(False)
 		
-		add_chapter=self.tree.get_widget("add_chapter")
+		add_chapter=self.tree.get_object("add_chapter")
 		add_chapter.set_sensitive(title_marked)
 		
-		del_chapter=self.tree.get_widget("del_chapter")
+		del_chapter=self.tree.get_object("del_chapter")
 		del_chapter.set_sensitive(chapter_marked)
 		
-		main_preview=self.tree.get_widget("main_preview")
+		main_preview=self.tree.get_object("main_preview")
 		main_preview.set_sensitive(chapter_marked)
 		
-		prop_chapter=self.tree.get_widget("prop_chapter")
+		prop_chapter=self.tree.get_object("prop_chapter")
 		prop_chapter.set_sensitive(chapter_marked)
 		
 		value=False
@@ -882,7 +881,7 @@ class main_window:
 				value=True
 				break
 	
-		main_go=self.tree.get_widget("main_go")
+		main_go=self.tree.get_object("main_go")
 		main_go.set_sensitive(value)
 		self.set_video_values()
 
@@ -897,37 +896,37 @@ class main_window:
 			found2=self.structure[title]
 			found=found2[chapter]
 			
-			w=self.tree.get_widget("oaspect")
+			w=self.tree.get_object("oaspect")
 			if (found["aspect"])>1.5:
 				w.set_text("16:9")
 			else:
 				w.set_text("4:3")
 				
-			w=self.tree.get_widget("o_size")
+			w=self.tree.get_object("o_size")
 			w.set_text(str(found["owidth"])+"x"+str(found["oheight"]))
 			
-			w=self.tree.get_widget("leng")
+			w=self.tree.get_object("leng")
 			w.set_text(str(found["olength"]))
 			
-			w=self.tree.get_widget("vrate")
+			w=self.tree.get_object("vrate")
 			w.set_text(str(found["vrate"]))
 			
-			w=self.tree.get_widget("arate")
+			w=self.tree.get_object("arate")
 			w.set_text(str(found["arate"]))
 			
-			w=self.tree.get_widget("eleng")
+			w=self.tree.get_object("eleng")
 			speed1,speed2=devede_other.get_speedup(found)
 			length=devede_other.calcula_tamano_parcial(found["vrate"],found["arate"],found["filesize"],found["olength"],len(found["sub_list"]),found["ismpeg"],found["cutting"],speed1,speed2)
 			#length=int(((found["vrate"]+found["arate"])*found["olength"])/8000)
 			w.set_text(str(int(length/1000)))
 			
-			w=self.tree.get_widget("achap")
+			w=self.tree.get_object("achap")
 			if found["lchapters"]==0:
 				w.set_text(_("no chapters"))
 			else:
 				w.set_text(str(int(found["lchapters"])))
 			
-			w=self.tree.get_widget("video_format")
+			w=self.tree.get_object("video_format")
 			if found["fps"]==25:
 				w.set_text("25 (PAL)")
 			elif found["fps"]==30:
@@ -938,28 +937,28 @@ class main_window:
 			else:
 				w.set_text(str(int(found["fps"])))
 			
-			w=self.tree.get_widget("fsizem")
+			w=self.tree.get_object("fsizem")
 			w.set_text(str(found["width"])+"x"+str(found["height"]))
 
 		else:
 
-			w=self.tree.get_widget("oaspect")
+			w=self.tree.get_object("oaspect")
 			w.set_text("")
-			w=self.tree.get_widget("o_size")
+			w=self.tree.get_object("o_size")
 			w.set_text("")
-			w=self.tree.get_widget("leng")
+			w=self.tree.get_object("leng")
 			w.set_text("")
-			w=self.tree.get_widget("vrate")
+			w=self.tree.get_object("vrate")
 			w.set_text("")
-			w=self.tree.get_widget("arate")
+			w=self.tree.get_object("arate")
 			w.set_text("")
-			w=self.tree.get_widget("eleng")
+			w=self.tree.get_object("eleng")
 			w.set_text("")
-			w=self.tree.get_widget("achap")
+			w=self.tree.get_object("achap")
 			w.set_text("")
-			w=self.tree.get_widget("video_format")
+			w=self.tree.get_object("video_format")
 			w.set_text("")
-			w=self.tree.get_widget("fsizem")
+			w=self.tree.get_object("fsizem")
 			w.set_text("")
 			
 		total=devede_other.calcula_tamano_total(self.structure,self.global_vars["menu_sound_duration"],self.disctocreate)
@@ -967,7 +966,7 @@ class main_window:
 		
 		tamano,minvrate,maxvrate = devede_other.get_dvd_size(self.tree,self.disctocreate)
 		
-		w=self.tree.get_widget("usage")
+		w=self.tree.get_object("usage")
 		if total>tamano:
 			w.set_fraction(1.0)
 			addv=1
@@ -1009,7 +1008,7 @@ class main_window:
 		if self.current_title_selected<0:
 			self.current_title_selected=0
 	
-		ltitles=self.tree.get_widget("ltitles")
+		ltitles=self.tree.get_object("ltitles")
 		ltitles.get_selection().select_path((self.current_title_selected,))
 
 	
@@ -1045,7 +1044,7 @@ class main_window:
 		if counter<self.current_file_selected:
 			self.current_file_selected=counter
 		
-		lchapters=self.tree.get_widget("lchapters")
+		lchapters=self.tree.get_object("lchapters")
 		lchapters.get_selection().select_path( (self.current_file_selected-1,))
 
 		
