@@ -25,7 +25,6 @@ import stat
 import pygtk # for testing GTK version number
 pygtk.require ('2.0')
 import gtk
-import gtk.glade
 import gobject
 import sys
 import gc
@@ -427,18 +426,17 @@ class file_properties(newfile):
 		self.structure=structure
 		self.callback_refresh=callback_refresh
 		
-		self.tree=gtk.glade.XML(self.gladefile,"wfile",domain="devede")
-		self.tree.signal_autoconnect(self)
-		self.window=self.tree.get_widget("wfile")
+		self.tree=devede_other.create_tree(self,"wfile",self.gladefile)
+		self.window=self.tree.get_object("wfile")
 		self.window.show()
 		self.window.drag_dest_set(gtk.DEST_DEFAULT_MOTION | gtk.DEST_DEFAULT_HIGHLIGHT | gtk.DEST_DEFAULT_DROP,[ ( "text/plain", 0, 80 ), ( "video/*", 0, 81) ],gtk.gdk.ACTION_COPY)
-		w = self.tree.get_widget("expander_advanced")
+		w = self.tree.get_object("expander_advanced")
 		w.set_expanded(self.global_vars["expand_advanced"])
 		
 		if global_vars["PAL"]:
-			w=self.tree.get_widget("video_pal")
+			w=self.tree.get_object("video_pal")
 		else:
-			w=self.tree.get_widget("video_ntsc")
+			w=self.tree.get_object("video_ntsc")
 		w.set_active(True)
 		
 		# Model and view for subtitles
@@ -447,7 +445,7 @@ class file_properties(newfile):
 		# third: codepage
 		
 		self.sub_model=gtk.ListStore(gobject.TYPE_INT, gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING)
-		self.sub_tree=self.tree.get_widget("sub_treeview")
+		self.sub_tree=self.tree.get_object("sub_treeview")
 		self.sub_tree.set_model(self.sub_model)
 		render1=gtk.CellRendererText()
 		column1=gtk.TreeViewColumn(_("Subtitle"),render1,text=1)
@@ -462,19 +460,19 @@ class file_properties(newfile):
 		# Model and view for audio tracks
 		
 		self.audio_model=gtk.ListStore(gobject.TYPE_STRING)
-		self.audio_view=self.tree.get_widget("audiotrack")
+		self.audio_view=self.tree.get_object("audiotrack")
 		self.audio_view.set_model(self.audio_model)
 		audiorender=gtk.CellRendererText()
 		self.audio_view.pack_start(audiorender,True)
 		self.audio_view.add_attribute(audiorender,"text",0)
 		
-		w1 = self.tree.get_widget("subtitles_label")
-		w2 = self.tree.get_widget("frame_special")
-		w3 = self.tree.get_widget("gop12")
-		w4 = self.tree.get_widget("res1280x720")
-		w5 = self.tree.get_widget("res1920x1080")
-		w6 = self.tree.get_widget("subtitles_list")
-		w7 = self.tree.get_widget("res160x128")
+		w1 = self.tree.get_object("subtitles_label")
+		w2 = self.tree.get_object("frame_special")
+		w3 = self.tree.get_object("gop12")
+		w4 = self.tree.get_object("res1280x720")
+		w5 = self.tree.get_object("res1920x1080")
+		w6 = self.tree.get_object("subtitles_list")
+		w7 = self.tree.get_object("res160x128")
 
 		if (self.disctocreate == "divx"):
 			w1.show()
@@ -493,16 +491,16 @@ class file_properties(newfile):
 			w6.show()
 			w7.hide()
 		
-		w=self.tree.get_widget("noaudiotracks")
+		w=self.tree.get_object("noaudiotracks")
 		w.hide()
 		
-		w=self.tree.get_widget("file_split_frame")
+		w=self.tree.get_object("file_split_frame")
 		if (self.disctocreate=="vcd"):
 			w.show()
 		else:
 			w.hide()
 		
-		w = self.tree.get_widget("frame_division") # SPLIT THE FILES IN CHAPTERS FOR EASY SEEKING
+		w = self.tree.get_object("frame_division") # SPLIT THE FILES IN CHAPTERS FOR EASY SEEKING
 		if (self.disctocreate == "dvd"):
 			w.show()
 		else:
@@ -518,17 +516,17 @@ class file_properties(newfile):
 				self.read_file_values(the_chapter["path"],False) # get all the values in FILE_VALUES
 				self.file_properties=copy.deepcopy(the_chapter)
 				self.change_file=True # we are changing the file name manually
-				w=self.tree.get_widget("moviefile")
+				w=self.tree.get_object("moviefile")
 				print "Pongo nombre por propiedades"
 				w.set_filename(self.file_properties["path"])
 			else:
 				w1.set_sensitive(False)
 		else:
 			if (self.global_vars["filmpath"]!=""):
-				w=self.tree.get_widget("moviefile")
+				w=self.tree.get_object("moviefile")
 				w.set_current_folder(self.global_vars["filmpath"])
 		
-		w=self.tree.get_widget("moviefile")
+		w=self.tree.get_object("moviefile")
 		self.file_filter_videos=gtk.FileFilter()
 		self.file_filter_videos.set_name(_("Video files"))
 		if sys.platform!="win32":
@@ -548,9 +546,9 @@ class file_properties(newfile):
 		self.set_film_buttons()
 		if (self.chapter!=-1): # we want to modify a chapter
 			print "Modificando"
-			w=self.tree.get_widget("fileaccept")
+			w=self.tree.get_object("fileaccept")
 			w.set_sensitive(True)
-			w=self.tree.get_widget("preview_film")
+			w=self.tree.get_object("preview_film")
 			w.set_sensitive(True)
 		
 		print "Fin"
@@ -570,22 +568,22 @@ class file_properties(newfile):
 		
 		""" Returns the resolution desired by the user as a single number """
 		
-		if (self.tree.get_widget("res160x128").get_active()):
+		if (self.tree.get_object("res160x128").get_active()):
 			return 8
-		if (self.tree.get_widget("res1920x1080").get_active()):
+		if (self.tree.get_object("res1920x1080").get_active()):
 			return 7
-		if (self.tree.get_widget("res1280x720").get_active()):
+		if (self.tree.get_object("res1280x720").get_active()):
 			return 6
 		
-		if (self.tree.get_widget("res720x480").get_active()):
+		if (self.tree.get_object("res720x480").get_active()):
 			return 1
-		if (self.tree.get_widget("res704x480").get_active()):
+		if (self.tree.get_object("res704x480").get_active()):
 			return 2
-		if (self.tree.get_widget("res480x480").get_active()):
+		if (self.tree.get_object("res480x480").get_active()):
 			return 3
-		if (self.tree.get_widget("res352x480").get_active()):
+		if (self.tree.get_object("res352x480").get_active()):
 			return 4
-		if (self.tree.get_widget("res352x240").get_active()):
+		if (self.tree.get_object("res352x240").get_active()):
 			return 5
 		return 0
 
@@ -598,16 +596,16 @@ class file_properties(newfile):
 		if self.file_properties==None:
 			return
 		
-		w1=self.tree.get_widget("video_rate")
+		w1=self.tree.get_object("video_rate")
 		vrate=w1.get_value()
-		w2=self.tree.get_widget("audio_rate")
+		w2=self.tree.get_object("audio_rate")
 		arate=w2.get_value()
 		resx,resy,use_widescreen,vrate,arate=self.get_recomended_resolution(vrate, arate, self.get_desired_resolution())
 		self.file_properties["width"]=resx
 		self.file_properties["height"]=resy
 		w1.set_value(vrate)
 		w2.set_value(arate)
-		w=self.tree.get_widget("aspect_ratio_4_3")
+		w=self.tree.get_object("aspect_ratio_4_3")
 		if ((resx<720) or (resy<480)) and (self.disctocreate!="divx"):
 			w.set_active(True)
 
@@ -622,92 +620,92 @@ class file_properties(newfile):
 		""" Fills the file_properties list with the values expressed in the widgets """
 
 		if len(self.file_properties["audio_list"])>0:
-			w=self.tree.get_widget("audiotrack")
+			w=self.tree.get_object("audiotrack")
 			pos=w.get_active()
 			if (pos==-1):
 				pos=0
 			self.file_properties["audio_stream"]=self.file_properties["audio_list"][pos]
 			
 
-		w=self.tree.get_widget("blackbars")
+		w=self.tree.get_object("blackbars")
 		if w.get_active():
 			self.file_properties["blackbars"]=0
 		else:
 			self.file_properties["blackbars"]=1
 	
-		w=self.tree.get_widget("trell")
+		w=self.tree.get_object("trell")
 		self.file_properties["trellis"]=w.get_active()
 	
 		self.file_properties["mbd"]=0
-		w=self.tree.get_widget("mbd1")
+		w=self.tree.get_object("mbd1")
 		if w.get_active():
 			self.file_properties["mbd"]=1
-		w=self.tree.get_widget("mbd2")
+		w=self.tree.get_object("mbd2")
 		if w.get_active():
 			self.file_properties["mbd"]=2
 		
 		self.file_properties["deinterlace"]="none"
-		w=self.tree.get_widget("deinterlace_lb")
+		w=self.tree.get_object("deinterlace_lb")
 		if w.get_active():
 			self.file_properties["deinterlace"]="lb"
-		w=self.tree.get_widget("deinterlace_md")
+		w=self.tree.get_object("deinterlace_md")
 		if w.get_active():
 			self.file_properties["deinterlace"]="md"
-		w=self.tree.get_widget("deinterlace_fd")
+		w=self.tree.get_object("deinterlace_fd")
 		if w.get_active():
 			self.file_properties["deinterlace"]="fd"
-		w=self.tree.get_widget("deinterlace_l5")
+		w=self.tree.get_object("deinterlace_l5")
 		if w.get_active():
 			self.file_properties["deinterlace"]="l5"
-		w=self.tree.get_widget("deinterlace_yadif")
+		w=self.tree.get_object("deinterlace_yadif")
 		if w.get_active():
 			self.file_properties["deinterlace"]="yadif"
 		
-		w=self.tree.get_widget("ismpeg")
+		w=self.tree.get_object("ismpeg")
 		self.file_properties["ismpeg"]=w.get_active()
 
-		w=self.tree.get_widget("copy_audio")
+		w=self.tree.get_object("copy_audio")
 		self.file_properties["copy_audio"]=w.get_active()
 
-		w=self.tree.get_widget("sound51")
+		w=self.tree.get_object("sound51")
 		self.file_properties["sound51"]=w.get_active()
 
-		w=self.tree.get_widget("gop12")
+		w=self.tree.get_object("gop12")
 		self.file_properties["gop12"]=w.get_active()
 
-		w=self.tree.get_widget("do_chapters")
+		w=self.tree.get_object("do_chapters")
 		if w.get_active():
-			w=self.tree.get_widget("chapter_long")
+			w=self.tree.get_object("chapter_long")
 			self.file_properties["lchapters"]=w.get_value()
 		else:
 			self.file_properties["lchapters"]=0
 	
-		w=self.tree.get_widget("audiodelay")
+		w=self.tree.get_object("audiodelay")
 		self.file_properties["adelay"]=float(w.get_value())
 		
-		w=self.tree.get_widget("video_rate")
+		w=self.tree.get_object("video_rate")
 		self.file_properties["vrate"]=int(w.get_value())
-		w=self.tree.get_widget("audio_rate")
+		w=self.tree.get_object("audio_rate")
 		self.file_properties["arate"]=int(w.get_value())
 	
-		w=self.tree.get_widget("full_length")
+		w=self.tree.get_object("full_length")
 		if w.get_active():
 			self.file_properties["cutting"]=0
 		else:
-			w=self.tree.get_widget("first_half")
+			w=self.tree.get_object("first_half")
 			if w.get_active():
 				self.file_properties["cutting"]=1
 			else:
 				self.file_properties["cutting"]=2
 
-		w=self.tree.get_widget("video_pal")
+		w=self.tree.get_object("video_pal")
 		if w.get_active():
 			self.file_properties["fps"]=25
 		else:
 			self.file_properties["fps"]=30
 	
 		if (self.disctocreate=="dvd") or (self.disctocreate=="divx"):
-			w=self.tree.get_widget("aspect_ratio_16_9")
+			w=self.tree.get_object("aspect_ratio_16_9")
 			if w.get_active():
 				self.file_properties["aspect"]=1.77777777
 			else:
@@ -717,35 +715,35 @@ class file_properties(newfile):
 
 		self.file_properties["resolution"]=self.get_desired_resolution()
 	
-		w=self.tree.get_widget("custom_params")
+		w=self.tree.get_object("custom_params")
 		self.file_properties["params"]=w.get_text()
 
-		w=self.tree.get_widget("custom_params_vf")
+		w=self.tree.get_object("custom_params_vf")
 		self.file_properties["params_vf"]=w.get_text()
 		
-		w=self.tree.get_widget("custom_params_lavcopts")
+		w=self.tree.get_object("custom_params_lavcopts")
 		self.file_properties["params_lavc"]=w.get_text()
 		
 		if (self.disctocreate=="divx"):
-			w=self.tree.get_widget("custom_params_lameopts")
+			w=self.tree.get_object("custom_params_lameopts")
 			self.file_properties["params_lame"]=w.get_text()
 
-		w=self.tree.get_widget("rotation0")
+		w=self.tree.get_object("rotation0")
 		if w.get_active():
 			self.file_properties["rotate"]=0 # no rotation
-		w=self.tree.get_widget("rotation90")
+		w=self.tree.get_object("rotation90")
 		if w.get_active():
 			self.file_properties["rotate"]=90 # rotate 90 degrees clockwise
-		w=self.tree.get_widget("rotation180")
+		w=self.tree.get_object("rotation180")
 		if w.get_active():
 			self.file_properties["rotate"]=180 # rotate 180 degrees
-		w=self.tree.get_widget("rotation270")
+		w=self.tree.get_object("rotation270")
 		if w.get_active():
 			self.file_properties["rotate"]=270 # rotate 90 degrees counter-clockwise
 		
-		w=self.tree.get_widget("hmirror")
+		w=self.tree.get_object("hmirror")
 		self.file_properties["hmirror"]=w.get_active()
-		w=self.tree.get_widget("vmirror")
+		w=self.tree.get_object("vmirror")
 		self.file_properties["vmirror"]=w.get_active()
 
 	# Callbacks
@@ -763,7 +761,7 @@ class file_properties(newfile):
 	
 	def on_sub_remove_clicked(self,widget):
 		
-		w=self.tree.get_widget("sub_treeview")
+		w=self.tree.get_object("sub_treeview")
 		try:
 			ctree,iter=w.get_selection().get_selected()
 			subtitle=ctree.get_value(iter,0)
@@ -773,8 +771,8 @@ class file_properties(newfile):
 		if subtitle==-1:
 			return
 
-		newtree=gtk.glade.XML(self.gladefile,"wdel_subtitle",domain="devede")
-		window=newtree.get_widget("wdel_subtitle")
+		newtree=devede_other.create_tree(self,"wdel_subtitle",self.gladefile,False)
+		window=newtree.get_object("wdel_subtitle")
 		window.show()
 		ret=window.run()
 		window.hide()
@@ -790,7 +788,7 @@ class file_properties(newfile):
 	
 	def on_filecancel_clicked(self,widget):
 
-		w=self.tree.get_widget("expander_advanced")
+		w=self.tree.get_object("expander_advanced")
 		self.global_vars["expand_advanced"]=w.get_expanded()
 		self.window.destroy()
 		self.window=None
@@ -799,7 +797,7 @@ class file_properties(newfile):
 
 	def on_fileaccept_clicked(self,widget):
 		
-		w=self.tree.get_widget("expander_advanced")
+		w=self.tree.get_object("expander_advanced")
 		self.global_vars["expand_advanced"]=w.get_expanded()
 		self.get_widgets()
 		if self.chapter==-1: # add this file as a new chapter
@@ -829,13 +827,13 @@ class file_properties(newfile):
 		
 		""" clears the subtitle filechooser """
 		
-		w=self.tree.get_widget("subtitles_chooser")
+		w=self.tree.get_object("subtitles_chooser")
 		w.unselect_all()
 	
 
 	def on_moviefile_file_set(self,widget):
 		
-		w=self.tree.get_widget("moviefile")
+		w=self.tree.get_object("moviefile")
 		filename=widget.get_filename()
 		
 		print "File changed to "+str(filename)
@@ -871,7 +869,7 @@ class file_properties(newfile):
 		
 		""" Detects the change in the option PAL/NTSC """
 		
-		w=self.tree.get_widget("video_pal")
+		w=self.tree.get_object("video_pal")
 		self.pal=w.get_active()
 		self.set_resolution()
 		self.adjust_resolution()
@@ -906,13 +904,13 @@ class file_properties(newfile):
 		if self.file_properties==None:
 			return
 		
-		w=self.tree.get_widget("aspect_ratio_16_9")
+		w=self.tree.get_object("aspect_ratio_16_9")
 		if w.get_active()==False:
 			return
 
 		self.set_resolution()
 		if (self.file_properties["width"]<720) or (self.file_properties["height"]<480):
-			w=self.tree.get_widget("res720x480")
+			w=self.tree.get_object("res720x480")
 			w.set_active(True)
 
 
@@ -981,7 +979,7 @@ class file_properties(newfile):
 				extension2=filename[-3:]
 				print "Extensiones: "+str(extension3)+" "+str(extension2)
 				if (0!=sub_extensions3.count(extension3)) or (0!=sub_extensions2.count(extension2)): # is a subtitle
-					current_file=self.tree.get_widget("moviefile").get_filename()
+					current_file=self.tree.get_object("moviefile").get_filename()
 					if (current_file=="") or (current_file==None):
 						devede_dialogs.show_error(self.gladefile,_("Please, add a movie file before adding subtitles."))
 						return
@@ -994,7 +992,7 @@ class file_properties(newfile):
 						self.set_global_values()
 					return
 
-		w=self.tree.get_widget("moviefile")
+		w=self.tree.get_object("moviefile")
 		print "Adding "+str(lista[0])
 		w.set_filename(str(lista[0]))
 
@@ -1014,15 +1012,15 @@ class file_properties(newfile):
 			res1="240"
 			res2="480"
 
-		w=self.tree.get_widget("res720x480")
+		w=self.tree.get_object("res720x480")
 		w.set_label("720x"+res2)
-		w=self.tree.get_widget("res704x480")
+		w=self.tree.get_object("res704x480")
 		w.set_label("704x"+res2)
-		w=self.tree.get_widget("res480x480")
+		w=self.tree.get_object("res480x480")
 		w.set_label("480x"+res2)
-		w=self.tree.get_widget("res352x480")
+		w=self.tree.get_object("res352x480")
 		w.set_label("352x"+res2)
-		w=self.tree.get_widget("res352x240")
+		w=self.tree.get_object("res352x240")
 		w.set_label("352x"+res1)
 
 
@@ -1033,26 +1031,26 @@ class file_properties(newfile):
 		dsize,minvid,maxvid=devede_other.get_dvd_size(None,self.disctocreate)
 
 		if self.disctocreate=="vcd":
-			w=self.tree.get_widget("video_rate")
+			w=self.tree.get_object("video_rate")
 			w.set_value(1152)
-			w=self.tree.get_widget("audio_rate")
+			w=self.tree.get_object("audio_rate")
 			w.set_value(224)
 		elif (self.disctocreate=="svcd") or (self.disctocreate=="cvd"):
-			w=self.tree.get_widget("audio_rate")
+			w=self.tree.get_object("audio_rate")
 			w.set_range(64,384)
 		else:
-			w=self.tree.get_widget("audio_rate")
+			w=self.tree.get_object("audio_rate")
 			w.set_range(128,448)
 			
 		if self.disctocreate!="vcd":
-			w=self.tree.get_widget("video_rate")
+			w=self.tree.get_object("video_rate")
 			w.set_range(minvid,maxvid)
 
 		if self.file_properties==None:
 			return
 
-		w1=self.tree.get_widget("aspect_ratio_4_3")
-		w2=self.tree.get_widget("aspect_ratio_16_9")
+		w1=self.tree.get_object("aspect_ratio_4_3")
+		w2=self.tree.get_object("aspect_ratio_16_9")
 		w1.set_active(True)
 		if (self.disctocreate=="dvd") or (self.disctocreate=="divx"):
 			w1.set_sensitive(True)
@@ -1066,126 +1064,126 @@ class file_properties(newfile):
 			w2.set_sensitive(False)
 
 		if self.file_properties["resolution"]==0: # auto resolution
-			w=self.tree.get_widget("resauto")
+			w=self.tree.get_object("resauto")
 		elif self.file_properties["resolution"]==1: # 720x480
-			w=self.tree.get_widget("res720x480")
+			w=self.tree.get_object("res720x480")
 		elif self.file_properties["resolution"]==2: # 704x480
-			w=self.tree.get_widget("res704x480")
+			w=self.tree.get_object("res704x480")
 		elif self.file_properties["resolution"]==3: # 480x480
-			w=self.tree.get_widget("res480x480")
+			w=self.tree.get_object("res480x480")
 		elif self.file_properties["resolution"]==4: # 352x480
-			w=self.tree.get_widget("res352x480")
+			w=self.tree.get_object("res352x480")
 		elif self.file_properties["resolution"]==6: # 1280x720
-			w=self.tree.get_widget("res1280x720")
+			w=self.tree.get_object("res1280x720")
 		elif self.file_properties["resolution"]==7: # 1920x1080
-			w=self.tree.get_widget("res1920x1080")
+			w=self.tree.get_object("res1920x1080")
 		elif self.file_properties["resolution"]==8: # 160x128
-			w=self.tree.get_widget("res160x128")
+			w=self.tree.get_object("res160x128")
 		else:
-			w=self.tree.get_widget("res352x240")
+			w=self.tree.get_object("res352x240")
 	
 		w.set_active(True)
 	
-		w=self.tree.get_widget("trell")
+		w=self.tree.get_object("trell")
 		w.set_active(self.file_properties["trellis"])
 	
 		if self.file_properties["mbd"]==0:
-			w=self.tree.get_widget("mbd")
+			w=self.tree.get_object("mbd")
 		elif self.file_properties["mbd"]==1:
-			w=self.tree.get_widget("mbd1")
+			w=self.tree.get_object("mbd1")
 		else:
-			w=self.tree.get_widget("mbd2")
+			w=self.tree.get_object("mbd2")
 		w.set_active(True)
 	
 		if self.file_properties["deinterlace"]=="none":
-			w=self.tree.get_widget("deinterlace")
+			w=self.tree.get_object("deinterlace")
 		else:
-			w=self.tree.get_widget("deinterlace_"+self.file_properties["deinterlace"])
+			w=self.tree.get_object("deinterlace_"+self.file_properties["deinterlace"])
 		w.set_active(True)
 	
-		w=self.tree.get_widget("ismpeg")
+		w=self.tree.get_object("ismpeg")
 		w.set_active(self.file_properties["ismpeg"])
 
-		w=self.tree.get_widget("copy_audio")
+		w=self.tree.get_object("copy_audio")
 		w.set_active(self.file_properties["copy_audio"])
 	
-		w=self.tree.get_widget("sound51")
+		w=self.tree.get_object("sound51")
 		w.set_active(self.file_properties["sound51"])
 		
-		w=self.tree.get_widget("gop12")
+		w=self.tree.get_object("gop12")
 		w.set_active(self.file_properties["gop12"])
 	
-		w=self.tree.get_widget("custom_params")
+		w=self.tree.get_object("custom_params")
 		w.set_text(self.file_properties["params"])
 
-		w=self.tree.get_widget("custom_params_lavcopts")
+		w=self.tree.get_object("custom_params_lavcopts")
 		w.set_text(self.file_properties["params_lavc"])
 		
-		w=self.tree.get_widget("custom_params_vf")
+		w=self.tree.get_object("custom_params_vf")
 		w.set_text(self.file_properties["params_vf"])
 		
 		if (self.disctocreate=="divx"):
-			w=self.tree.get_widget("custom_params_lameopts")
+			w=self.tree.get_object("custom_params_lameopts")
 			w.set_text(self.file_properties["params_lame"])
 	
-		vrate=self.tree.get_widget("video_rate")
+		vrate=self.tree.get_object("video_rate")
 		vrate.set_value(self.file_properties["vrate"])
-		arate=self.tree.get_widget("audio_rate")
+		arate=self.tree.get_object("audio_rate")
 		arate.set_value(self.file_properties["arate"])
-		w=self.tree.get_widget("audiodelay")
+		w=self.tree.get_object("audiodelay")
 		w.set_value(self.file_properties["adelay"])
 		if self.file_properties["blackbars"]==0:
-			w=self.tree.get_widget("blackbars")
+			w=self.tree.get_object("blackbars")
 		else:
-			w=self.tree.get_widget("scalepict")
+			w=self.tree.get_object("scalepict")
 		w.set_active(True)
 		
-		w=self.tree.get_widget("do_chapters")
+		w=self.tree.get_object("do_chapters")
 		if self.file_properties["lchapters"]==0:
 			w.set_active(False)
-			w=self.tree.get_widget("chapter_long")
+			w=self.tree.get_object("chapter_long")
 			w.set_sensitive(False)
 		else:
 			w.set_active(True)
-			w=self.tree.get_widget("chapter_long")
+			w=self.tree.get_object("chapter_long")
 			w.set_sensitive(True)
 			w.set_value(self.file_properties["lchapters"])
 		
 		if self.file_properties["fps"]==25:
-			w=self.tree.get_widget("video_pal")
+			w=self.tree.get_object("video_pal")
 		else:
-			w=self.tree.get_widget("video_ntsc")
+			w=self.tree.get_object("video_ntsc")
 		w.set_active(True)
 	
 		if self.file_properties["cutting"]==0:
-			w=self.tree.get_widget("full_length")
+			w=self.tree.get_object("full_length")
 		elif self.file_properties["cutting"]==1:
-			w=self.tree.get_widget("first_half")
+			w=self.tree.get_object("first_half")
 		else:
-			w=self.tree.get_widget("second_half")
+			w=self.tree.get_object("second_half")
 		w.set_active(True)
 	
 		print "Rotate: "+str(self.file_properties["rotate"])
 		if self.file_properties["rotate"]==0:
-			w=self.tree.get_widget("rotation0")
+			w=self.tree.get_object("rotation0")
 		elif self.file_properties["rotate"]==90:
-			w=self.tree.get_widget("rotation90")
+			w=self.tree.get_object("rotation90")
 		elif self.file_properties["rotate"]==180:
-			w=self.tree.get_widget("rotation180")
+			w=self.tree.get_object("rotation180")
 		elif self.file_properties["rotate"]==270:
-			w=self.tree.get_widget("rotation270")
+			w=self.tree.get_object("rotation270")
 		w.set_active(True)
 		
-		w=self.tree.get_widget("hmirror")
+		w=self.tree.get_object("hmirror")
 		w.set_active(self.file_properties["hmirror"])
-		w=self.tree.get_widget("vmirror")
+		w=self.tree.get_object("vmirror")
 		w.set_active(self.file_properties["vmirror"])
 
 		self.audio_model.clear()
 		if len(self.file_properties["audio_list"])>0:
-			w=self.tree.get_widget("hasaudiotracks")
+			w=self.tree.get_object("hasaudiotracks")
 			w.show()
-			w=self.tree.get_widget("noaudiotracks")
+			w=self.tree.get_object("noaudiotracks")
 			w.hide()
 			position=0
 			for track in self.file_properties["audio_list"]:
@@ -1194,12 +1192,12 @@ class file_properties(newfile):
 				self.audio_model.set_value(iterator,0,track)
 				position+=1
 			print "Pista seleccionada: "+str(self.file_properties["audio_stream"])
-			w=self.tree.get_widget("audiotrack")
+			w=self.tree.get_object("audiotrack")
 			w.set_active(self.file_properties["audio_list"].index(self.file_properties["audio_stream"]))
 		else:
-			w=self.tree.get_widget("hasaudiotracks")
+			w=self.tree.get_object("hasaudiotracks")
 			w.hide()
-			w=self.tree.get_widget("noaudiotracks")
+			w=self.tree.get_object("noaudiotracks")
 			w.show()
 
 		self.refresh_subtitles()
@@ -1222,7 +1220,7 @@ class file_properties(newfile):
 			self.sub_model.set_value(iterator,2,subtitle["sub_codepage"])
 			self.sub_model.set_value(iterator,3,subtitle["sub_language"])
 			position+=1
-		w=self.tree.get_widget("sub_treeview")
+		w=self.tree.get_object("sub_treeview")
 		w.get_selection().select_path(0)
 		self.set_film_buttons()
 			
@@ -1231,11 +1229,11 @@ class file_properties(newfile):
 
 		""" Enables or disables all the buttons, based in the current disk type and other widgets """
 
-		w1=self.tree.get_widget("fileaccept")
-		w=self.tree.get_widget("moviefile")
+		w1=self.tree.get_object("fileaccept")
+		w=self.tree.get_object("moviefile")
 		cfile=w.get_filename()
 		
-		w=self.tree.get_widget("preview_film")
+		w=self.tree.get_object("preview_film")
 		if (cfile=="") or (cfile==None):
 			w.set_sensitive(False)
 			w1.set_sensitive(False)
@@ -1243,13 +1241,13 @@ class file_properties(newfile):
 			w.set_sensitive(True)
 			w1.set_sensitive(True)
 
-		w=self.tree.get_widget("ismpeg")
+		w=self.tree.get_object("ismpeg")
 		if w.get_active():
 			grupo2=False
 		else:
 			grupo2=True
 
-		w=self.tree.get_widget("copy_audio")
+		w=self.tree.get_object("copy_audio")
 		if w.get_active():
 			copy_audio=False
 		else:
@@ -1269,12 +1267,12 @@ class file_properties(newfile):
 			grupo1=grupo2
 		
 		if (self.disctocreate=="dvd") or (self.disctocreate=="divx"):
-			w=self.tree.get_widget("sound51")
+			w=self.tree.get_object("sound51")
 			if w.get_active():
-				w=self.tree.get_widget("audio_rate")
+				w=self.tree.get_object("audio_rate")
 				w.set_range(384,448)		
 			else:
-				w=self.tree.get_widget("audio_rate")
+				w=self.tree.get_object("audio_rate")
 				w.set_range(128,448)
 
 		grupo3=grupo2
@@ -1284,54 +1282,54 @@ class file_properties(newfile):
 		except:
 			grupo3=False
 
-		w=self.tree.get_widget("video_rate")
+		w=self.tree.get_object("video_rate")
 		w.set_sensitive(grupo1)
-		w=self.tree.get_widget("audio_rate")
+		w=self.tree.get_object("audio_rate")
 		w.set_sensitive(grupo1 and copy_audio)
-		w=self.tree.get_widget("gop12")
+		w=self.tree.get_object("gop12")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("sound51")
+		w=self.tree.get_object("sound51")
 		if not(grupo1 and copy_audio):
 			w.set_active(False)
 		w.set_sensitive(sound51 and copy_audio)
-		w=self.tree.get_widget("resauto")
+		w=self.tree.get_object("resauto")
 		w.set_sensitive(grupo1)
-		w=self.tree.get_widget("res352x240")
+		w=self.tree.get_object("res352x240")
 		w.set_sensitive(grupo1)
-		w=self.tree.get_widget("res352x480")
+		w=self.tree.get_object("res352x480")
 		w.set_sensitive(grupo1)
-		w=self.tree.get_widget("res480x480")
+		w=self.tree.get_object("res480x480")
 		w.set_sensitive(grupo1)
-		w=self.tree.get_widget("res704x480")
+		w=self.tree.get_object("res704x480")
 		w.set_sensitive(grupo1)
-		w=self.tree.get_widget("res720x480")
+		w=self.tree.get_object("res720x480")
 		w.set_sensitive(grupo1)
 	
-		w=self.tree.get_widget("full_length")
+		w=self.tree.get_object("full_length")
 		w.set_sensitive(grupo3)
-		w=self.tree.get_widget("first_half")
+		w=self.tree.get_object("first_half")
 		w.set_sensitive(grupo3)
-		w=self.tree.get_widget("second_half")
+		w=self.tree.get_object("second_half")
 		w.set_sensitive(grupo3)
-		w=self.tree.get_widget("video_pal")
+		w=self.tree.get_object("video_pal")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("video_ntsc")
+		w=self.tree.get_object("video_ntsc")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("audiodelay")
+		w=self.tree.get_object("audiodelay")
 		w.set_sensitive(copy_audio)
-		w=self.tree.get_widget("blackbars")
+		w=self.tree.get_object("blackbars")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("scalepict")
+		w=self.tree.get_object("scalepict")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("custom_params")
+		w=self.tree.get_object("custom_params")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("custom_params_vf")
+		w=self.tree.get_object("custom_params_vf")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("custom_params_lavcopts")
+		w=self.tree.get_object("custom_params_lavcopts")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("custom_params_lameopts")
+		w=self.tree.get_object("custom_params_lameopts")
 		w.set_sensitive(copy_audio)
-		w2=self.tree.get_widget("lameopts_label")
+		w2=self.tree.get_object("lameopts_label")
 		if self.disctocreate=="divx":
 			w.show()
 			w2.show()
@@ -1339,42 +1337,42 @@ class file_properties(newfile):
 			w.hide()
 			w2.hide()
 
-		w=self.tree.get_widget("trell")
+		w=self.tree.get_object("trell")
 		w.set_sensitive(grupo2)
 		
-		w=self.tree.get_widget("rotation0")
+		w=self.tree.get_object("rotation0")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("rotation90")
+		w=self.tree.get_object("rotation90")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("rotation180")
+		w=self.tree.get_object("rotation180")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("rotation270")
+		w=self.tree.get_object("rotation270")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("hmirror")
+		w=self.tree.get_object("hmirror")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("vmirror")
+		w=self.tree.get_object("vmirror")
 		w.set_sensitive(grupo2)
 		
-		w=self.tree.get_widget("mbd")
+		w=self.tree.get_object("mbd")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("mbd1")
+		w=self.tree.get_object("mbd1")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("mbd2")
+		w=self.tree.get_object("mbd2")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("deinterlace")
+		w=self.tree.get_object("deinterlace")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("deinterlace_lb")
+		w=self.tree.get_object("deinterlace_lb")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("deinterlace_md")
+		w=self.tree.get_object("deinterlace_md")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("deinterlace_fd")
+		w=self.tree.get_object("deinterlace_fd")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("deinterlace_l5")
+		w=self.tree.get_object("deinterlace_l5")
 		w.set_sensitive(grupo2)
-		w=self.tree.get_widget("audiotrack")
+		w=self.tree.get_object("audiotrack")
 		w.set_sensitive(grupo2)
-		w1=self.tree.get_widget("aspect_ratio_4_3")
-		w2=self.tree.get_widget("aspect_ratio_16_9")
+		w1=self.tree.get_object("aspect_ratio_4_3")
+		w2=self.tree.get_object("aspect_ratio_16_9")
 		if (self.disctocreate == "dvd") or (self.disctocreate == "divx"):
 			w1.set_sensitive(grupo2)
 			w2.set_sensitive(grupo2)
@@ -1382,8 +1380,8 @@ class file_properties(newfile):
 			w1.set_sensitive(False)
 			w2.set_sensitive(False)
 
-		w1=self.tree.get_widget("sub_remove")
-		w2=self.tree.get_widget("sub_add")
+		w1=self.tree.get_object("sub_remove")
+		w2=self.tree.get_object("sub_add")
 		try:
 			sub_number=len(self.file_properties["sub_list"])
 			if sub_number==0:
@@ -1410,42 +1408,42 @@ class file_properties(newfile):
 		else:
 			empty=False
 	
-		w=self.tree.get_widget("o_size2")
+		w=self.tree.get_object("o_size2")
 		if empty:
 			w.set_text("")
 		else:
 			w.set_text(str(self.file_properties["owidth"])+"x"+str(self.file_properties["oheight"]))
 
-		w=self.tree.get_widget("leng2")
+		w=self.tree.get_object("leng2")
 		if empty:
 			w.set_text("")
 		else:
 			w.set_text(str(self.file_properties["olength"]))
 		
-		w=self.tree.get_widget("fps")
+		w=self.tree.get_object("fps")
 		if empty:
 			w.set_text("")
 		else:
 			w.set_text(str(self.file_properties["ofps"]))
 
-		w=self.tree.get_widget("vrate2")
+		w=self.tree.get_object("vrate2")
 		if empty:
 			w.set_text("")
 		else:
 			w.set_text(str(self.file_properties["ovrate"]))
 
-		w=self.tree.get_widget("arate2")
+		w=self.tree.get_object("arate2")
 		if empty:
 			w.set_text("")
 		else:
 			w.set_text(str(self.file_properties["oarate"]))
 	
-		w=self.tree.get_widget("video_rate")
+		w=self.tree.get_object("video_rate")
 		vrate=w.get_value()
-		w=self.tree.get_widget("audio_rate")
+		w=self.tree.get_object("audio_rate")
 		arate=w.get_value()
 	
-		w=self.tree.get_widget("full_length")
+		w=self.tree.get_object("full_length")
 		if w.get_active():
 			divide=False
 			divide2=0
@@ -1453,22 +1451,22 @@ class file_properties(newfile):
 			divide=True
 			divide2=1
 		
-		w=self.tree.get_widget("eleng2")
+		w=self.tree.get_object("eleng2")
 		if empty:
 			w.set_text("")
 		else:
-			w2=self.tree.get_widget("ismpeg")
+			w2=self.tree.get_object("ismpeg")
 			props={}
 			props["ofps"]=self.file_properties["ofps"]
 			props["ofps2"]=self.file_properties["ofps2"]
-			w3=self.tree.get_widget("video_pal")
+			w3=self.tree.get_object("video_pal")
 			if w3.get_active():
 				props["fps"]=25
 			else:
 				props["fps"]=30
-			w3=self.tree.get_widget("copy_audio")
+			w3=self.tree.get_object("copy_audio")
 			props["copy_audio"]=w3.get_active()
-			w3=self.tree.get_widget("ismpeg")
+			w3=self.tree.get_object("ismpeg")
 			props["ismpeg"]=w3.get_active()
 			print "Props: "+str(props)
 			speed1,speed2=devede_other.get_speedup(props)
@@ -1483,7 +1481,7 @@ class file_properties(newfile):
 			#l+=int((8.0*float(len(self.file_properties["sub_list"]))*self.file_properties["olength"])/8000.0)
 			w.set_text(str(int(l/1000)))
 		
-		w=self.tree.get_widget("f_size2")
+		w=self.tree.get_object("f_size2")
 		if empty:
 			w.set_text("")
 		else:
@@ -1495,25 +1493,49 @@ class ask_subtitle:
 	def __init__(self,gladefile,filepath,filename=None):
 
 		self.gladefile=gladefile
-		self.tree=gtk.glade.XML(self.gladefile,"add_subtitle",domain="devede")
-		self.tree.signal_autoconnect(self)
-		w=self.tree.get_widget("sub_codepage")
-		w.child.set_text("ISO-8859-1")
-		w=self.tree.get_widget("sub_language")
-		w.child.set_text("EN (ENGLISH)")
-		self.window=self.tree.get_widget("add_subtitle")
+		self.tree=devede_other.create_tree(self,"add_subtitle2",self.gladefile)
+		self.lang_list=[]
+		self.cpage_list=[]
+		
+		pos=0
+		chelement=0
+		languages=open(os.path.join(self.gladefile,"languages.lst"),"r")
+		w=self.tree.get_object("sub_language")
+		for element in languages:
+			if element[:-1]=="EN (ENGLISH)":
+				chelement=pos
+			w.append_text(element[:-1])
+			self.lang_list.append(element[:-1])
+			pos+=1
+		languages.close()
+		w.set_active(chelement)
+		
+		pos=0
+		chelement=0
+		codepages=open(os.path.join(self.gladefile,"codepages.lst"),"r")
+		w=self.tree.get_object("sub_codepage")
+		for element in codepages:
+			if element[:-1]=="ISO-8859-1":
+				chelement=pos
+			w.append_text(element[:-1])
+			self.cpage_list.append(element[:-1])
+			pos+=1
+		codepages.close()
+		w.set_active(chelement)
+
+		self.window=self.tree.get_object("add_subtitle")
 		if (filepath!=""):
-			w=self.tree.get_widget("subtitles_chooser")
+			w=self.tree.get_object("subtitles_chooser")
 			w.set_current_folder(filepath)
 		if (filename!=None) and (filename!=""):
-			self.tree.get_widget("subtitles_chooser").set_filename(filename)
+			self.tree.get_object("subtitles_chooser").set_filename(filename)
 		self.window.show()
 		self.set_status()
 
 
 	def on_clear_subtitles_clicked(self,widget):
 
-		file=self.tree.get_widget("subtitles_chooser")
+		file=self.tree.get_object("subtitles_chooser")
 		file.unselect_all()
 
 
@@ -1524,14 +1546,14 @@ class ask_subtitle:
 	
 	def set_status(self):
 		
-		filename=self.tree.get_widget("subtitles_chooser").get_filename()
+		filename=self.tree.get_object("subtitles_chooser").get_filename()
 		
 		if (filename=="") or (filename==None):
 			status=False
 		else:
 			status=True
 			
-		w=self.tree.get_widget("sub_accept")
+		w=self.tree.get_object("sub_accept")
 		w.set_sensitive(status)
 
 	
@@ -1540,13 +1562,13 @@ class ask_subtitle:
 		ret=self.window.run()
 		if ret==-5: # OK
 			ret_val={}
-			w=self.tree.get_widget("subtitles_chooser")
+			w=self.tree.get_object("subtitles_chooser")
 			ret_val["subtitles"]=w.get_filename()
-			w=self.tree.get_widget("sub_codepage")
-			ret_val["sub_codepage"]=w.child.get_text()
-			w=self.tree.get_widget("sub_language")
-			ret_val["sub_language"]=w.child.get_text()
-			w=self.tree.get_widget("sub_up")
+			w=self.tree.get_object("sub_codepage")
+			ret_val["sub_codepage"]=self.cpage_list[w.get_active()]
+			w=self.tree.get_object("sub_language")
+			ret_val["sub_language"]=self.lang_list[w.get_active()]
+			w=self.tree.get_object("sub_up")
 			ret_val["subtitles_up"]=w.get_active()
 		else:
 			ret_val=None
