@@ -30,6 +30,7 @@ import stat
 import sys
 import shutil
 import cairo
+import gtk
 
 if sys.platform == 'win32':
 	import devede_executor
@@ -337,7 +338,7 @@ def get_dvd_size(tree,disctocreate):
 		videorate for the current video disk """
 	
 	if tree!=None:
-		w=tree.get_widget("dvdsize")
+		w=tree.get_object("dvdsize")
 		active=w.get_active()
 		
 		# here we choose the size in Mbytes for the media
@@ -396,4 +397,14 @@ def get_picture_type(filename):
 	f.close()
 	print "tipo: "+str(ftype)
 	return ftype
+
+
+def create_tree(sobject,filename,builderpath="",autoconnect=True):
 	
+	tree=gtk.Builder()
+	tree.set_translation_domain("devede")
+	tree.add_from_file(os.path.join(builderpath,filename+".ui"))
+	if autoconnect:
+		tree.connect_signals(sobject)
+
+	return tree
